@@ -48,9 +48,11 @@ using std::string;
 
 #ifndef DEBUG
 #  define debug(format, ...)	while (0) { }
+#  define DEBUG_ATTR_UNUSED XFSTT_ATTR_UNUSED
 #  define STATIC static
 #else
 #  define debug(format, ...)	fprintf(stderr, format, ##__VA_ARGS__)
+#  define DEBUG_ATTR_UNUSED
 #  define STATIC
 #endif
 
@@ -81,7 +83,7 @@ public:
 	}
 	// XXX:	virtual ~RandomAccessFile()	{}
 
-	int openError()			{ return (absbase == 0); }
+	int openError()			{ return (absbase == nullptr); }
 	void closeRAFile();
 
 	void reset()			{ ptr = base; }
@@ -94,7 +96,7 @@ public:
 	uint32_t calcChecksum();
 
 	// these inlined functions are generic and should be optimized
-	// for specific processors (alignment, endianess, ...)
+	// for specific processors (alignment, endianness, ...)
 
 	int8_t readSByte() {
 		int8_t i = ptr[0];
@@ -200,7 +202,7 @@ struct Point {
 struct FontInfo {
 	uint16_t firstChar, lastChar;
 	uint8_t panose[10];
-	int	faceLength;
+	size_t faceLength;
 	char	faceName[32];
 };
 
@@ -1037,7 +1039,7 @@ enum {
 	S45ROUND	= 0x77,	// super round 45 degrees
 	SLOOP		= 0x17,	// set loop counter
 	SMD		= 0x1A,	// set minimum distance
-	INSTCTRL	= 0x8E,	// intruction execution control
+	INSTCTRL	= 0x8E,	// instruction execution control
 
 	// scan conversion control
 
@@ -1219,7 +1221,7 @@ enum {
 	LOOPCALL	= 0x2A,	// loop and call
 	IDEF		= 0x89,	// instruction definition
 
-	// miscelleneous
+	// miscellaneous
 
 	DBG		= 0x4F,	// debug
 	GETINFO		= 0x88	// get info about glyph and scaler
