@@ -20,6 +20,8 @@
 #include "config.h"
 
 #include <string>
+#include <vector>
+
 #include <stdint.h>
 #include <stdio.h>
 #include <string.h>
@@ -70,14 +72,23 @@ patchttf(int argc, char **argv)
 	}
 
 	struct stat st;
-	stat(inTTname.c_str(), &st);
-	int flen = st.st_size;
-	uint8_t *buf = new uint8_t[flen + 3];
+	if (fstat(fileno(fp), &st) < 0) {
+		printf("Cannot stat \"%s\"\n", inTTname.c_str());
+		fclose(fp);
+		return -1;
+	}
+
+	size_t flen = st.st_size;
+	std::vector<uint8_t> buf(flen + 3);
 	for (int ibuf = 0; ibuf < 3; ++ibuf)
 		buf[flen + ibuf] = 0;
-	printf("TTFsize = %d\n", flen);
+	printf("TTFsize = %zd\n", flen);
 
-	fread(buf, 1, flen, fp);
+	if (fread(buf.data(), 1, flen, fp) != flen) {
+		printf("Cannot read \"%s\"\n", inTTname.c_str());
+		fclose(fp);
+		return -1;
+	}
 	fclose(fp);
 
 	// patch as requested
@@ -86,7 +97,7 @@ patchttf(int argc, char **argv)
 		if (p[0] != '-' || p[1] != 'p')
 			return -i;
 
-		int addr = 0;
+		size_t addr = 0;
 		p = argv[i+1];
 		if (p[0] != '0' || p[1] != 'x')
 			return -i;
@@ -108,7 +119,7 @@ patchttf(int argc, char **argv)
 			nhex <<= 4;
 			nhex |= (c > '9') ? c - 'a' + 10 : c - '0';
 
-			printf("patch %05X = %02X -> %02X\n",
+			printf("patch %05zX = %02X -> %02X\n",
 			       addr, buf[addr], nhex);
 
 			buf[addr] = nhex;
@@ -118,31 +129,34 @@ patchttf(int argc, char **argv)
 	// update the checksums
 	int nTables = (buf[4] << 8) + buf[5];
 	//printf("nTables = %d\n", nTables);
-	uint8_t *headTable = 0;
+	uint8_t *headTable = nullptr;
 	for (int iTable = 0; iTable < nTables; ++iTable) {
-		uint8_t *b = &buf[12 + iTable * 16];
+		uint8_t *b = &(buf.data()[12 + iTable * 16]);
 		int name = (b[0] << 24) + (b[1] << 16) + (b[2] << 8) + b[3];
 		int offset = (b[8] << 24) + (b[9] << 16) + (b[10] << 8) + b[11];
 		int length = (b[12] << 24) + (b[13] << 16) + (b[14] << 8) + b[15];
 		//printf("offset = %08X, length = %08X\n", offset, length);
-		int check = checksum(buf + offset, length);
+		int check = checksum(buf.data() + offset, length);
 		b[4] = (uint8_t)(check >> 24);
 		b[5] = (uint8_t)(check >> 16);
 		b[6] = (uint8_t)(check >> 8);
 		b[7] = (uint8_t)check;
 		//printf("checksum[%d] = %08X\n", iTable, check);
 		if (name == 0x68656164) {
-			headTable = buf + offset;
+			headTable = buf.data() + offset;
 			//printf("headOffset = %08X\n", offset);
 		}
 	}
 
-	int check = checksum(buf, flen) - 0xB1B0AFBA;
-	//printf("csAdjust = %08X\n", check);
-	headTable[8] = (uint8_t)(check >> 24);
-	headTable[9] = (uint8_t)(check >> 16);
-	headTable[10] = (uint8_t)(check >> 8);
-	headTable[11] = (uint8_t)check;
+	if (headTable) {
+		int check = checksum(buf.data(), flen) - 0xB1B0AFBA;
+
+		//printf("csAdjust = %08X\n", check);
+		headTable[8] = (uint8_t)(check >> 24);
+		headTable[9] = (uint8_t)(check >> 16);
+		headTable[10] = (uint8_t)(check >> 8);
+		headTable[11] = (uint8_t)check;
+	}
 
 	// write the patched file
 	fp = fopen(outTTname.c_str(), "wb");
@@ -150,10 +164,13 @@ patchttf(int argc, char **argv)
 		printf("Cannot write \"%s\"\n", outTTname.c_str());
 		return -1;
 	}
-	fwrite(buf, 1, flen, fp);
-	fclose(fp);
+	if (fwrite(buf.data(), 1, flen, fp) != flen) {
+		printf("Cannot write \"%s\"\n", outTTname.c_str());
+		fclose(fp);
+		return -1;
+	}
 
-	delete[] buf;
+	fclose(fp);
 
 	return 0;
 }
